From 4f98bf352b7fa9712b240210cdfcd70f648d0621 Mon Sep 17 00:00:00 2001
From: willwh <willwh@297364.no-reply.drupal.org>
Date: Sat, 26 Mar 2016 11:30:28 -0500
Subject: [PATCH] Issue #2694783 by willwh, mikeryan: Switch
 ConfigurationEntities for Plugins

---
 src/Entity/MigrationGroup.php        |  2 +-
 src/Event/MigratePrepareRowEvent.php | 14 +++++++-------
 2 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/src/Entity/MigrationGroup.php b/src/Entity/MigrationGroup.php
index 579ae678..589f1d7d 100644
--- a/src/Entity/MigrationGroup.php
+++ b/src/Entity/MigrationGroup.php
@@ -8,7 +8,7 @@
 namespace Drupal\migrate_plus\Entity;
 
 use Drupal\Core\Config\Entity\ConfigEntityBase;
-use Drupal\migrate\Entity\MigrationInterface;
+use Drupal\migrate\Plugin\MigrationInterface;
 
 /**
  * Defines the Migration Group entity.
diff --git a/src/Event/MigratePrepareRowEvent.php b/src/Event/MigratePrepareRowEvent.php
index edd10bcf..e64ac406 100644
--- a/src/Event/MigratePrepareRowEvent.php
+++ b/src/Event/MigratePrepareRowEvent.php
@@ -7,7 +7,7 @@
 
 namespace Drupal\migrate_plus\Event;
 
-use Drupal\migrate\Entity\MigrationInterface;
+use Drupal\migrate\Plugin\MigrationInterface;
 use Drupal\migrate\Plugin\MigrateSourceInterface;
 use Drupal\migrate\Row;
 use Symfony\Component\EventDispatcher\Event;
@@ -25,16 +25,16 @@ class MigratePrepareRowEvent extends Event {
   protected $row;
 
   /**
-   * Migration entity.
+   * Migration source plugin.
    *
    * @var \Drupal\migrate\Plugin\MigrateSourceInterface
    */
   protected $source;
 
   /**
-   * Migration entity.
+   * Migration plugin.
    *
-   * @var \Drupal\migrate\Entity\MigrationInterface
+   * @var \Drupal\migrate\Plugin\MigrationInterface
    */
   protected $migration;
 
@@ -47,7 +47,7 @@ class MigratePrepareRowEvent extends Event {
    * @param \Drupal\migrate\Plugin\MigrateSourceInterface $source
    *   Source plugin that is the source of the event.
    *
-   * @param \Drupal\migrate\Entity\MigrationInterface $migration
+   * @param \Drupal\migrate\Plugin\MigrationInterface $migration
    *   Migration entity.
    */
   public function __construct(Row $row, MigrateSourceInterface $source, MigrationInterface $migration) {
@@ -77,9 +77,9 @@ class MigratePrepareRowEvent extends Event {
   }
 
   /**
    * Gets the migration entity.
    *
-   * @return \Drupal\migrate\Entity\MigrationInterface
+   * @return \Drupal\migrate\Plugin\MigrationInterface
    *   The migration entity being imported.
    */
   public function getMigration() {
@@ -77,9 +77,9 @@ class MigratePrepareRowEvent extends Event {
 
   /**
-   * Gets the migration entity.
+   * Gets the migration plugin.
    *
-- 
GitLab